@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2017-2019 by the Free Software Foundation, Inc.
+# Copyright (C) 2017-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of Django-Mailman.
 #
@@ -93,7 +93,7 @@ class TestBootstrapTags(SimpleTestCase):
             '<form> {% bootstrap_form form %}')
         rendered_template = template.render(context=context)
         label_field = '''
-<label class="control-label" for="id_datetime">
+<label class="control-label font-weight-bold" for="id_datetime">
     Datetime
 </label>'''
         self.assertInHTML(label_field, rendered_template)
